pywws.ToTwitter — pywws 13.03_7f9fc90 documentation

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.03_7f9fc90 documentation »
- Programmes et des modules Python »

# pywws.ToTwitter

Poster un message sur Twitter

    usage: python RunModule.py ToTwitter [options] data_dir file
    options are:
     -h | --help  display this help
    data_dir is the root directory of the weather data
    file is the text file to be uploaded

Ce module poste un bref message sur Twitter <https://twitter.com/> _. Avant de poster sur Twitter, vous devez créer un compte et autoriser pywws en exécutant le programme :py: mod: TwitterAuth. Voir :doc: ../Guides/twitter obtenir les instructions détaillées.

Fonctions

`main`([argv]) |

Classes

`ToTwitter`(params) |

class `pywws.ToTwitter.` `ToTwitter`(params)
  `Upload`(tweet)
  `UploadFile`(file)

`pywws.ToTwitter.` `main`(argv=None)

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.03_7f9fc90 documentation »
- Programmes et des modules Python »